@@ -23,6 +23,7 @@ from nxtomomill.converter.hdf5.acquisition.baseacquisition import _ask_for_file_
 from nxtomomill.converter.hdf5.acquisition.multitomo import MultiTomoAcquisition
 from nxtomomill.models.h52nx._acquisitionstep import AcquisitionStep
 from nxtomomill.models.h52nx import H52nxModel
+from tomoscan.utils.io import filter_esrf_mounting_points
 
 from .acquisition.baseacquisition import BaseAcquisition
 from .acquisition.standardacquisition import StandardAcquisition
@@ -174,6 +175,15 @@ class _H5ToNxConverter(BaseConverter):
         return self._acquisitions
 
     def preprocess(self):
+        # clean path
+        if self._configuration.input_file is not None:
+            self._configuration.input_file = filter_esrf_mounting_points(
+                self._configuration.input_file
+            )
+        if self._configuration.output_file is not None:
+            self._configuration.output_file = filter_esrf_mounting_points(
+                self._configuration.output_file
+            )
         self._preprocess_urls()
         self._check_conversion_is_possible()
 
